Authors
=======

- Alec Deason <alecwd@uw.edu>
- James Collins <collijk@uw.edu>
- Michelle Park <hpark3@uw.edu>
- Abraham Flaxman <abie@uw.edu>
- Everett Mumford <emumford@uw.edu>
- Jonathan Joseph <jjoseph7@uw.edu>
- Reed Sorenson <rsoren@uw.edu>

Current Maintainers
-------------------

- James Collins <collijk@uw.edu>
- Michelle Park <hpark3@uw.edu>
- Abraham Flaxman <abie@uw.edu>
